<p align="center">
    <a target="_blank" href='https://url.cn/Z4lzPLaF'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F1040x100-tencent.jpg" width="100%"/>
    </a>   
</p>
<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/office/robot.html">项目官网</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
    <a target="_blank" href='https://github.com/CoderWanFeng/PyOfficeRobot'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/PyOfficeRobot.svg?style=social" alt="github star"/>
    </a>
    	<a target="_blank" href='https://gitee.com/CoderWanFeng//PyOfficeRobot/'>
		<img src='https://gitee.com/CoderWanFeng//PyOfficeRobot/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/wx-JkgOUoJhb-7ZESxl93w">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>

</p>




# 又一个微信聊天机器人横空出世了，人人可用！


之前给大家分享过一个微信机器人：[一个15分钟的视频，教你用Python创建自己的微信聊天机器人！](http://t.cn/A66p30bI)

但是之前这个机器人，需要基于网页版才能用(有网页版微信的同学，还可以去继续用)；然而很多朋友的微信，是不能登录网页版微信的。

> 有没有一种微信机器人，任何人的微信都可以用，不需要网页微信功能呢？


在经过技术检索和开发以后，支持所有微信使用的：**PyOfficeRobot**来啦~

## 1、安装PyOfficeRobot

1行命令，安装PyOfficeRobot这个库。[安装视频](https://www.bilibili.com/video/BV1Xa411u7yU/)
```
pip install -i https://mirrors.aliyun.com/pypi/simple/ PyOfficeRobot -U
```

## 2、视频教程

- ⭐全套源码：[Github](https://github.com/CoderWanFeng/PyOfficeRobot)


| 功能说明       | 视频 |代码 |
| -------------- | -------- |-------- |
| 🔥001-项目发布 | [点我直达](https://www.bilibili.com/video/BV1Xa411u7yU)     |[点我直达](https://mp.weixin.qq.com/s/6slx8hyv_WuK7v5Nzt3XKQ)     |
| 002-自动发消息 | [点我直达](https://www.bilibili.com/video/BV1Jt4y1j7F1)     |[点我直达](https://github.com/CoderWanFeng/PyOfficeRobot/blob/main/demo/001-message.py)     |
| 003-自动发文件 | [点我直达](https://www.bilibili.com/video/BV1te4y1y7Ro)     |[点我直达](https://github.com/CoderWanFeng/PyOfficeRobot/blob/main/demo/003-file.py)     |
| 004-根据关键词，自动回复 | [点我直达](https://www.bilibili.com/video/BV1fV4y1M7ju)     |[点我直达](https://github.com/CoderWanFeng/PyOfficeRobot/blob/main/demo/004-%E6%A0%B9%E6%8D%AE%E5%85%B3%E9%94%AE%E8%AF%8D%E5%9B%9E%E5%A4%8D.py)     |
| ⌚005-定时自动发消息 | [点我直达](https://www.bilibili.com/video/BV1m8411b7LZ/)     |[点我直达](https://github.com/CoderWanFeng/PyOfficeRobot/blob/main/demo/06-%E5%AE%9A%E6%97%B6.py)     |
| 006-自己加功能 | [点我直达](https://www.bilibili.com/video/BV14R4y127h6)     |     |
| ⭐007-独立使用 | [点我直达](https://www.bilibili.com/video/BV1SY411y7Uh)     |[点我直达](https://github.com/CoderWanFeng/PyOfficeRobot)     |
| 08-收集群信息 | [点我直达](https://www.bilibili.com/video/BV1eD4y1g7yZ)     |[点我直达](https://mp.weixin.qq.com/s/crjGYUzyQ3iIN3Sx2UUucw)     |
| 09-发消息如何换行？ | [点我直达](https://www.bilibili.com/video/BV1Xg4y1s79z/)     |[点我直达](https://gitee.com/CoderWanFeng/PyOfficeRobot/blob/main/demo/08-new_line.py)     |
| 特别篇-微信 + ChatGPT | [点我直达](http://xhslink.com/zXZAeo)     |[点我直达](https://blog.51cto.com/u_15493782/6131326)     |
| 10-批量加好友 | [点我直达](https://www.bilibili.com/video/BV1DV4y1o7t2)     |[点我直达](https://gitee.com/CoderWanFeng/PyOfficeRobot/blob/main/PyOfficeRobot/api/friend.py)     |
| 11-定时群发 | [点我直达](https://www.bilibili.com/video/BV1Nm4y1C7N7)     |[点我直达](https://gitee.com/CoderWanFeng/PyOfficeRobot/blob/main/demo/11-%E5%AE%9A%E6%97%B6%E7%BE%A4%E5%8F%91/11-%E5%AE%9A%E6%97%B6%E7%BE%A4%E5%8F%91.py)     |

> 持续更新中，交流群：[点我加入](http://www.python4office.cn/wechat-group/)
#### 微信机器人-其它实现方式


| 功能说明       | 视频 |代码 |
| -------------- | -------- |-------- |
| 机器人.exe | [点我直达](https://www.bilibili.com/video/BV1Q64y1Z7TB/)     |     |
| ChatGPT版本 | [点我直达](https://www.bilibili.com/video/BV1Dx4y157qy)     |[点我直达](https://mp.weixin.qq.com/s/HJfLZILUOWn4TK8qk3DL9w)     |
| ⌚wxpy-24小时，后台运行 | [点我直达](https://www.bilibili.com/video/BV11L411L7oi/)     |[点我直达](https://mp.weixin.qq.com/s/ubJ1OhOFVKfFVT8sBNZ0pg)     |
| 企业微信机器人 |      |[点我直达](https://mp.weixin.qq.com/s/mt-ONvz0DdhbMB96eTZDKA)     |




## 3、功能Demo

我最近开源了这个库的全部源代码，功能正在开发中，欢迎大家参与开发~

- [演示代码](https://github.com/CoderWanFeng/PyOfficeRobot/tree/main/demo)

## 4、开发者

| 昵称      | 贡献                    | 时间             |
|---------|-----------------------|----------------|
| 雷杰 | 解决了微信更新后，不能发送消息和文件的问题 | 2023/7/6 00：30 |

---

![](https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg)


## ⭐Star 

[![Stargazers over time](https://starchart.cc/CoderWanFeng/PyOfficeRobot.svg)](https://starchart.cc/CoderWanFeng/PyOfficeRobot)


## 📕拓展资料


<p align="center" id='30讲自动化办公-banner'>
    <a target="_blank" href='http://gk.link/a/10E3B'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fauto-work.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='100本电子书-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/H3us6_7wg2QspGZfGtfDZw'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Febook.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='实战项目-banner'>
    <a target="_blank" href='http://www.python4office.cn/python-project-list/'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fproject.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='11个软件-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/uE1M8ESBQ3wJ_q-Cl1aNvg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fsoft-11.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='25个学习资源-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/_01V8I7rVkgvIIo7ygwwQA'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fpy-25-source.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='支付宝-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/TSnAjBs2dILSI_pM1pPznQ'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F%E8%81%94%E7%9B%9F%E5%B9%BF%E5%91%8A%2Falipay.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='外卖-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/fdQ0TbTocPvw-DAMsFUlVg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F%E8%81%94%E7%9B%9F%E5%B9%BF%E5%91%8A%2F%E5%A4%96%E5%8D%96-1040-100.jpg" width="100%"/>
    </a>   
</p>